@@ -14,6 +14,17 @@ use super::context::{ModuleContext, FunctionContext};
 use super::names;
 use super::types::*;
 
+#[derive(Debug)]
+pub struct ReaderPlugin;
+
+impl compiler::Plugin for ReaderPlugin {
+    fn generate(&self, module_ctxt: &mut ModuleContext, definition_name: &str, definition: &Definition) {
+        if module_ctxt.mode.is_none() {
+            gen_definition_reader(module_ctxt, definition_name, definition)
+        }
+    }
+}
+
 #[derive(Clone)]
 struct BoundaryTracker {
     tracker_name: String,
