@@ -10,6 +10,17 @@ use super::context::{ModuleContextMode, ModuleContext, FunctionContext};
 use super::names;
 use super::types::*;
 
+#[derive(Debug)]
+pub struct UnparserPlugin;
+
+impl compiler::Plugin for UnparserPlugin {
+    fn generate(&self, module_ctxt: &mut ModuleContext, definition_name: &str, definition: &Definition) {
+        if module_ctxt.mode.is_some() {
+            gen_definition_unparser(module_ctxt, definition_name, definition)
+        }
+    }
+}
+
 type ValueSource = Option<String>;
 
 #[derive(Clone)]
@@ -121,7 +132,7 @@ fn simple_pattern_unparser(
     let src = &vc.src;
     match p {
         SimplePattern::Any => {
-            match ctxt.m.mode {
+            match ctxt.m.mode() {
                 ModuleContextMode::TargetIOValue =>
                     item(seq!["_support::encode_embedded", parens![src.as_ref().unwrap().to_owned()]]),
                 ModuleContextMode::TargetAny =>
@@ -139,7 +150,7 @@ fn simple_pattern_unparser(
             }
         }
         SimplePattern::Embedded { .. } => {
-            match ctxt.m.mode {
+            match ctxt.m.mode() {
                 ModuleContextMode::TargetIOValue =>
                     item(seq!["preserves::value::Value::Embedded(preserves::value::IOValue::from(&**", src.as_ref().unwrap().to_owned(), ")).wrap()"]),
                 ModuleContextMode::TargetAny =>
